@@ -21,7 +21,7 @@ from PyQt4 import QtGui, QtCore
 from friture.audiobackend import SAMPLING_RATE
 
 # shared with spectrum_settings.py
-DEFAULT_FFT_SIZE = 7 #4096 points
+DEFAULT_FFT_SIZE = 8 #8192 points
 DEFAULT_FREQ_SCALE = 1 #log10
 DEFAULT_MAXFREQ = 20000
 DEFAULT_MINFREQ = 20
@@ -29,12 +29,13 @@ DEFAULT_SPEC_MIN = -100
 DEFAULT_SPEC_MAX = -20
 DEFAULT_WEIGHTING = 1 #A
 DEFAULT_SHOW_FREQ_LABELS = True
+DEFAULT_RESPONSE_TIME = 0.025
+DEFAULT_RESPONSE_TIME_INDEX = 0
 
 class Spectrum_Settings_Dialog(QtGui.QDialog):
 	def __init__(self, parent, logger):
 		QtGui.QDialog.__init__(self, parent)
 		
-		self.parent = parent
 		self.logger = logger
 		
 		self.setWindowTitle("Spectrum settings")
@@ -107,6 +108,14 @@ class Spectrum_Settings_Dialog(QtGui.QDialog):
 		self.comboBox_weighting.addItem("C")
 		self.comboBox_weighting.setCurrentIndex(DEFAULT_WEIGHTING)
 
+		self.comboBox_response_time = QtGui.QComboBox(self)
+		self.comboBox_response_time.setObjectName("response_time")
+		self.comboBox_response_time.addItem("25 ms (Impulse)")
+		self.comboBox_response_time.addItem("125 ms (Fast)")
+		self.comboBox_response_time.addItem("300 ms")
+		self.comboBox_response_time.addItem("1s (Slow)")
+		self.comboBox_response_time.setCurrentIndex(DEFAULT_RESPONSE_TIME_INDEX)
+
 		self.checkBox_showFreqLabels = QtGui.QCheckBox(self)
 		self.checkBox_showFreqLabels.setObjectName("showFreqLabels")
 		self.checkBox_showFreqLabels.setChecked(DEFAULT_SHOW_FREQ_LABELS)
@@ -119,6 +128,7 @@ class Spectrum_Settings_Dialog(QtGui.QDialog):
 		self.formLayout.addRow("Min:", self.spinBox_specmin)
 		self.formLayout.addRow("Max:", self.spinBox_specmax)
 		self.formLayout.addRow("Middle-ear weighting:", self.comboBox_weighting)
+		self.formLayout.addRow("Response time:", self.comboBox_response_time)
 		self.formLayout.addRow("Display max-frequency label:", self.checkBox_showFreqLabels)
 		
 		self.setLayout(self.formLayout)
@@ -126,19 +136,20 @@ class Spectrum_Settings_Dialog(QtGui.QDialog):
 		self.connect(self.comboBox_dual_channel, QtCore.SIGNAL('currentIndexChanged(int)'), self.dualchannelchanged)
 		self.connect(self.comboBox_fftsize, QtCore.SIGNAL('currentIndexChanged(int)'), self.fftsizechanged)
 		self.connect(self.comboBox_freqscale, QtCore.SIGNAL('currentIndexChanged(int)'), self.freqscalechanged)
-		self.connect(self.spinBox_minfreq, QtCore.SIGNAL('valueChanged(int)'), self.parent.setminfreq)
-		self.connect(self.spinBox_maxfreq, QtCore.SIGNAL('valueChanged(int)'), self.parent.setmaxfreq)
-		self.connect(self.spinBox_specmin, QtCore.SIGNAL('valueChanged(int)'), self.parent.setmin)
-		self.connect(self.spinBox_specmax, QtCore.SIGNAL('valueChanged(int)'), self.parent.setmax)
-		self.connect(self.comboBox_weighting, QtCore.SIGNAL('currentIndexChanged(int)'), self.parent.setweighting)
-		self.connect(self.checkBox_showFreqLabels, QtCore.SIGNAL('toggled(bool)'), self.parent.setShowFreqLabel)
+		self.connect(self.spinBox_minfreq, QtCore.SIGNAL('valueChanged(int)'), self.parent().setminfreq)
+		self.connect(self.spinBox_maxfreq, QtCore.SIGNAL('valueChanged(int)'), self.parent().setmaxfreq)
+		self.connect(self.spinBox_specmin, QtCore.SIGNAL('valueChanged(int)'), self.parent().setmin)
+		self.connect(self.spinBox_specmax, QtCore.SIGNAL('valueChanged(int)'), self.parent().setmax)
+		self.connect(self.comboBox_weighting, QtCore.SIGNAL('currentIndexChanged(int)'), self.parent().setweighting)
+		self.connect(self.comboBox_response_time, QtCore.SIGNAL('currentIndexChanged(int)'), self.responsetimechanged)
+		self.connect(self.checkBox_showFreqLabels, QtCore.SIGNAL('toggled(bool)'), self.parent().setShowFreqLabel)
 
 	# slot
 	def dualchannelchanged(self, index):
 		if index == 0:
-			self.parent.setdualchannels(False)
+			self.parent().setdualchannels(False)
 		else:
-			self.parent.setdualchannels(True)
+			self.parent().setdualchannels(True)
 
 	# slot
 	def fftsizechanged(self, index):
@@ -146,7 +157,7 @@ class Spectrum_Settings_Dialog(QtGui.QDialog):
 		if self.logger is not None:
 			self.logger.push("fft_size_changed slot %d %d %f" %(index, 2**index*32, 150000/2**index*32))
 		fft_size = 2**index*32
-		self.parent.setfftsize(fft_size)
+		self.parent().setfftsize(fft_size)
 	
 	# slot
 	def freqscalechanged(self, index):
@@ -154,9 +165,22 @@ class Spectrum_Settings_Dialog(QtGui.QDialog):
 		if self.logger is not None:
 			self.logger.push("freq_scale slot %d" %index)
 		if index == 1:
-			self.parent.PlotZoneSpect.setlogfreqscale()
+			self.parent().PlotZoneSpect.setlogfreqscale()
 		else:
-			self.parent.PlotZoneSpect.setlinfreqscale()
+			self.parent().PlotZoneSpect.setlinfreqscale()
+
+	# slot
+	def responsetimechanged(self, index):
+		if index == 0:
+			response_time = 0.025
+		elif index == 1:
+			response_time = 0.125
+		elif index == 2:
+			response_time = 0.3
+		elif index == 3:
+			response_time = 1.
+		self.logger.push("responsetimechanged slot %d %d" %(index, response_time))
+		self.parent().setresponsetime(response_time)
 
 	# method
 	def saveState(self, settings):
@@ -167,6 +191,7 @@ class Spectrum_Settings_Dialog(QtGui.QDialog):
 		settings.setValue("Min", self.spinBox_specmin.value())
 		settings.setValue("Max", self.spinBox_specmax.value())
 		settings.setValue("weighting", self.comboBox_weighting.currentIndex())
+		settings.setValue("responseTime", self.comboBox_response_time.currentIndex())
 		settings.setValue("showFreqLabels", self.checkBox_showFreqLabels.isChecked())
 
 	# method
@@ -185,5 +210,7 @@ class Spectrum_Settings_Dialog(QtGui.QDialog):
 		self.spinBox_specmax.setValue(colorMax)
 		(weighting, ok) = settings.value("weighting", DEFAULT_WEIGHTING).toInt()
 		self.comboBox_weighting.setCurrentIndex(weighting)
+		(responseTime, ok) = settings.value("responseTime", DEFAULT_RESPONSE_TIME_INDEX).toInt()
+		self.comboBox_response_time.setCurrentIndex(responseTime)
 		showFreqLabels = settings.value("showFreqLabels", DEFAULT_SHOW_FREQ_LABELS).toBool()
 		self.checkBox_showFreqLabels.setChecked(showFreqLabels)
